==> nebula-core-1.2.3.10-Release-sources.jar: com/bizunited/platform/core/service/file/NebulaFileService.java <==
package com.bizunited.platform.core.service.file;

/**
 * 技术中台，文件服务接口（单纯的文件服务接口）。在不同的业务系统中，涉及的文件管理方式是不一样的。
 * 例如，文件资料可能被保存到本地文件系统，并从本地文件系统中进行下载；业务系统中的文件资料也可能被保存到诸如阿里云对象存储系统中（使用阿里OSS API）；
 * 又或者被保存到Hadoop HDFS上。所以当前还没有完全脱离代码编写工作的当前技术中台版本，必须定义一个文件服务接口，以便技术中台能够提供一个默认的文件保存方式，
 * 以及不同的业务系统根据自己的文件资料保存要求，实现具体的文件资料保存逻辑<p>
 * 
 * 这里说明几点：<br>
 * 1、这个文件资料的保存、读取服务将被广泛用于技术中台服务中的各个服务，包括但不限于：模板草稿的保存和读取、模板样式的保存和读取、表单实例上附件的上传保存和读取、
 * 表单实例上图片的上传保存和读取，等等。<br>
 * 2、技术中台针对该文件服务接口，有一个默认的实现，既是kuiperFileServiceSimpleImpl，如果业务系统搭建时，没有特别实现kuiperFileService，
 * 那么kuiperFileServiceSimpleImpl的默认实现将其作用，文件资料将被保存在以kuiper.file.fileRoot配置的根目录下（默认实现）。
 * @author yinwenjie
 */
public interface NebulaFileService {
  /**
   * 保存文件服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件内容的保存时，该接口的服务实现将被调用。
   * @param relativePath 由技术中台中各功能模块，进行文件内容保存调用时，自行设定的基于文件保存根目录的相对路径。有的功能模块的文件保存调用时，可能传入，也可能不传入。
   * 传入的格式一定类似于“/relativePath1/relativePath2”
   * @param fileName 页面操作者在进行文件上传时，选定文件的原始名字，包括了文件的后缀名。
   * 注意这种上传性质的文件附件资料，其最大大小、允许的文件后缀，分别必须满足业务系统中设定的kuiper.file.maxFileSize属性和kuiper.file.whitePrefixs属性（不区分大小写）
   * @param fileRename 得到上传的文件后，技术中台系统会重命名这个文件名，以保证文件名在系统中的唯一性（但后缀会保持不变）；重命名的文件名会返回给该接口的实现者
   * 注意：这里有一种情况，就是需要保存的文件并不是由页面操作者明确上传的，而是因为技术中台自身的业务逻辑需要将某些信息作为文件内容进行保存的。
   * 例如在表单模板编辑时，对整个模板布局的json内容进行保存。那么这时，fileName参数和fileRename参数反应出来的值是相同的。
   * @param fileContext 文件内容。文件内容一定至少有1个byte。
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public void saveFile(String relativePath , String fileName , String fileRename , byte[] fileContext);
  
  /**
   * 删除文件服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件的删除时，该接口的服务实现将被调用。
   * @param relativePath 请参见saveFile方法中，对应的入参说明
   * @param fileName 描述当前删除的文件，在之前的文件上传操作时的原始文件名（包括后缀名）
   * @param fileRename 描述当前删除的文件，在之前的文件上传操作时，被技术中台重命名后的新的文件名（后缀名不会改变）
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public void deleteFile(String relativePath , String fileName , String fileRename);
  
  /**
   * 文件内容读取服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件内容的读取时，该接口的服务实现将被调用。
   * @param relativePath 请参见saveFile方法中，对应的入参说明
   * @param fileRename 描述当前文件(重命名以后的)，在之前的文件上传操作时，被技术中台重命名后的新的文件名（后缀名不会改变）
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public byte[] readFileContent(String relativePath , String fileRename);
}

==> nebula-core-2.0.2.11-Release-sources.jar: com/bizunited/platform/core/service/file/NebulaFileService.java <==
package com.bizunited.platform.core.service.file;

/**
 * 技术中台，文件服务接口（单纯的文件服务接口）。在不同的业务系统中，涉及的文件管理方式是不一样的。
 * 例如，文件资料可能被保存到本地文件系统，并从本地文件系统中进行下载；业务系统中的文件资料也可能被保存到诸如阿里云对象存储系统中（使用阿里OSS API）；
 * 又或者被保存到Hadoop HDFS上。所以当前还没有完全脱离代码编写工作的当前技术中台版本，必须定义一个文件服务接口，以便技术中台能够提供一个默认的文件保存方式，
 * 以及不同的业务系统根据自己的文件资料保存要求，实现具体的文件资料保存逻辑<p>
 * 
 * 这里说明几点：<br>
 * 1、这个文件资料的保存、读取服务将被广泛用于技术中台服务中的各个服务，包括但不限于：模板草稿的保存和读取、模板样式的保存和读取、表单实例上附件的上传保存和读取、
 * 表单实例上图片的上传保存和读取，等等。<br>
 * 2、技术中台针对该文件服务接口，有一个默认的实现，既是kuiperFileServiceSimpleImpl，如果业务系统搭建时，没有特别实现kuiperFileService，
 * 那么kuiperFileServiceSimpleImpl的默认实现将其作用，文件资料将被保存在以nebula.file.fileRoot配置的根目录下（默认实现）。
 * @author yinwenjie
 */
public interface NebulaFileService {
  /**
   * 保存文件服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件内容的保存时，该接口的服务实现将被调用。
   * @param relativePath 由技术中台中各功能模块，进行文件内容保存调用时，自行设定的基于文件保存根目录的相对路径。有的功能模块的文件保存调用时，可能传入，也可能不传入。
   * 传入的格式一定类似于“/relativePath1/relativePath2”
   * @param fileName 页面操作者在进行文件上传时，选定文件的原始名字，包括了文件的后缀名。
   * 注意这种上传性质的文件附件资料，其最大大小、允许的文件后缀，分别必须满足业务系统中设定的nebula.file.maxFileSize属性和nebula.file.whitePrefixs属性（不区分大小写）
   * @param fileRename 得到上传的文件后，技术中台系统会重命名这个文件名，以保证文件名在系统中的唯一性（但后缀会保持不变）；重命名的文件名会返回给该接口的实现者
   * 注意：这里有一种情况，就是需要保存的文件并不是由页面操作者明确上传的，而是因为技术中台自身的业务逻辑需要将某些信息作为文件内容进行保存的。
   * 例如在表单模板编辑时，对整个模板布局的json内容进行保存。那么这时，fileName参数和fileRename参数反应出来的值是相同的。
   * @param fileContext 文件内容。文件内容一定至少有1个byte。
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public void saveFile(String relativePath , String fileName , String fileRename , byte[] fileContext);
  
  /**
   * 删除文件服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件的删除时，该接口的服务实现将被调用。
   * @param relativePath 请参见saveFile方法中，对应的入参说明
   * @param fileName 描述当前删除的文件，在之前的文件上传操作时的原始文件名（包括后缀名）
   * @param fileRename 描述当前删除的文件，在之前的文件上传操作时，被技术中台重命名后的新的文件名（后缀名不会改变）
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public void deleteFile(String relativePath , String fileName , String fileRename);
  
  /**
   * 文件内容读取服务，当技术中台中涉及到文件附件的各个功能需要进行物理文件内容的读取时，该接口的服务实现将被调用。
   * @param relativePath 请参见saveFile方法中，对应的入参说明
   * @param fileRename 描述当前文件(重命名以后的)，在之前的文件上传操作时，被技术中台重命名后的新的文件名（后缀名不会改变）
   * @throws 如果处理过程出现问题，接口实现者只需要向方法外部抛出人任何一种runtimeException异常即可
   */
  public byte[] readFileContent(String relativePath , String fileRename);
}
